from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.System.Com
import win32more.Windows.Win32.System.UpdateAgent
import win32more.Windows.Win32.System.Variant
AddServiceFlag = Int32
asfAllowPendingRegistration: win32more.Windows.Win32.System.UpdateAgent.AddServiceFlag = 1
asfAllowOnlineRegistration: win32more.Windows.Win32.System.UpdateAgent.AddServiceFlag = 2
asfRegisterServiceWithAU: win32more.Windows.Win32.System.UpdateAgent.AddServiceFlag = 4
LIBID_WUApiLib: Guid = Guid('{b596cc9f-56e5-419e-a622-e01bb457431e}')
UPDATE_LOCKDOWN_WEBSITE_ACCESS: UInt32 = 1
WU_S_SERVICE_STOP: win32more.Windows.Win32.Foundation.HRESULT = 2359297
WU_S_SELFUPDATE: win32more.Windows.Win32.Foundation.HRESULT = 2359298
WU_S_UPDATE_ERROR: win32more.Windows.Win32.Foundation.HRESULT = 2359299
WU_S_MARKED_FOR_DISCONNECT: win32more.Windows.Win32.Foundation.HRESULT = 2359300
WU_S_REBOOT_REQUIRED: win32more.Windows.Win32.Foundation.HRESULT = 2359301
WU_S_ALREADY_INSTALLED: win32more.Windows.Win32.Foundation.HRESULT = 2359302
WU_S_ALREADY_UNINSTALLED: win32more.Windows.Win32.Foundation.HRESULT = 2359303
WU_S_ALREADY_DOWNLOADED: win32more.Windows.Win32.Foundation.HRESULT = 2359304
WU_S_SOME_UPDATES_SKIPPED_ON_BATTERY: win32more.Windows.Win32.Foundation.HRESULT = 2359305
WU_S_ALREADY_REVERTED: win32more.Windows.Win32.Foundation.HRESULT = 2359306
WU_S_SEARCH_CRITERIA_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = 2359312
WU_S_UH_INSTALLSTILLPENDING: win32more.Windows.Win32.Foundation.HRESULT = 2367509
WU_S_UH_DOWNLOAD_SIZE_CALCULATED: win32more.Windows.Win32.Foundation.HRESULT = 2367510
WU_S_SIH_NOOP: win32more.Windows.Win32.Foundation.HRESULT = 2379777
WU_S_DM_ALREADYDOWNLOADING: win32more.Windows.Win32.Foundation.HRESULT = 2383873
WU_S_METADATA_SKIPPED_BY_ENFORCEMENTMODE: win32more.Windows.Win32.Foundation.HRESULT = 2388225
WU_S_METADATA_IGNORED_SIGNATURE_VERIFICATION: win32more.Windows.Win32.Foundation.HRESULT = 2388226
WU_S_SEARCH_LOAD_SHEDDING: win32more.Windows.Win32.Foundation.HRESULT = 2392065
WU_S_AAD_DEVICE_TICKET_NOT_NEEDED: win32more.Windows.Win32.Foundation.HRESULT = 2392066
WU_E_NO_SERVICE: win32more.Windows.Win32.Foundation.HRESULT = -2145124351
WU_E_MAX_CAPACITY_REACHED: win32more.Windows.Win32.Foundation.HRESULT = -2145124350
WU_E_UNKNOWN_ID: win32more.Windows.Win32.Foundation.HRESULT = -2145124349
WU_E_NOT_INITIALIZED: win32more.Windows.Win32.Foundation.HRESULT = -2145124348
WU_E_RANGEOVERLAP: win32more.Windows.Win32.Foundation.HRESULT = -2145124347
WU_E_TOOMANYRANGES: win32more.Windows.Win32.Foundation.HRESULT = -2145124346
WU_E_INVALIDINDEX: win32more.Windows.Win32.Foundation.HRESULT = -2145124345
WU_E_ITEMNOTFOUND: win32more.Windows.Win32.Foundation.HRESULT = -2145124344
WU_E_OPERATIONINPROGRESS: win32more.Windows.Win32.Foundation.HRESULT = -2145124343
WU_E_COULDNOTCANCEL: win32more.Windows.Win32.Foundation.HRESULT = -2145124342
WU_E_CALL_CANCELLED: win32more.Windows.Win32.Foundation.HRESULT = -2145124341
WU_E_NOOP: win32more.Windows.Win32.Foundation.HRESULT = -2145124340
WU_E_XML_MISSINGDATA: win32more.Windows.Win32.Foundation.HRESULT = -2145124339
WU_E_XML_INVALID: win32more.Windows.Win32.Foundation.HRESULT = -2145124338
WU_E_CYCLE_DETECTED: win32more.Windows.Win32.Foundation.HRESULT = -2145124337
WU_E_TOO_DEEP_RELATION: win32more.Windows.Win32.Foundation.HRESULT = -2145124336
WU_E_INVALID_RELATIONSHIP: win32more.Windows.Win32.Foundation.HRESULT = -2145124335
WU_E_REG_VALUE_INVALID: win32more.Windows.Win32.Foundation.HRESULT = -2145124334
WU_E_DUPLICATE_ITEM: win32more.Windows.Win32.Foundation.HRESULT = -2145124333
WU_E_INVALID_INSTALL_REQUESTED: win32more.Windows.Win32.Foundation.HRESULT = -2145124332
WU_E_INSTALL_NOT_ALLOWED: win32more.Windows.Win32.Foundation.HRESULT = -2145124330
WU_E_NOT_APPLICABLE: win32more.Windows.Win32.Foundation.HRESULT = -2145124329
WU_E_NO_USERTOKEN: win32more.Windows.Win32.Foundation.HRESULT = -2145124328
WU_E_EXCLUSIVE_INSTALL_CONFLICT: win32more.Windows.Win32.Foundation.HRESULT = -2145124327
WU_E_POLICY_NOT_SET: win32more.Windows.Win32.Foundation.HRESULT = -2145124326
WU_E_SELFUPDATE_IN_PROGRESS: win32more.Windows.Win32.Foundation.HRESULT = -2145124325
WU_E_INVALID_UPDATE: win32more.Windows.Win32.Foundation.HRESULT = -2145124323
WU_E_SERVICE_STOP: win32more.Windows.Win32.Foundation.HRESULT = -2145124322
WU_E_NO_CONNECTION: win32more.Windows.Win32.Foundation.HRESULT = -2145124321
WU_E_NO_INTERACTIVE_USER: win32more.Windows.Win32.Foundation.HRESULT = -2145124320
WU_E_TIME_OUT: win32more.Windows.Win32.Foundation.HRESULT = -2145124319
WU_E_ALL_UPDATES_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2145124318
WU_E_EULAS_DECLINED: win32more.Windows.Win32.Foundation.HRESULT = -2145124317
WU_E_NO_UPDATE: win32more.Windows.Win32.Foundation.HRESULT = -2145124316
WU_E_USER_ACCESS_DISABLED: win32more.Windows.Win32.Foundation.HRESULT = -2145124315
WU_E_INVALID_UPDATE_TYPE: win32more.Windows.Win32.Foundation.HRESULT = -2145124314
WU_E_URL_TOO_LONG: win32more.Windows.Win32.Foundation.HRESULT = -2145124313
WU_E_UNINSTALL_NOT_ALLOWED: win32more.Windows.Win32.Foundation.HRESULT = -2145124312
WU_E_INVALID_PRODUCT_LICENSE: win32more.Windows.Win32.Foundation.HRESULT = -2145124311
WU_E_MISSING_HANDLER: win32more.Windows.Win32.Foundation.HRESULT = -2145124310
WU_E_LEGACYSERVER: win32more.Windows.Win32.Foundation.HRESULT = -2145124309
WU_E_BIN_SOURCE_ABSENT: win32more.Windows.Win32.Foundation.HRESULT = -2145124308
WU_E_SOURCE_ABSENT: win32more.Windows.Win32.Foundation.HRESULT = -2145124307
WU_E_WU_DISABLED: win32more.Windows.Win32.Foundation.HRESULT = -2145124306
WU_E_CALL_CANCELLED_BY_POLICY: win32more.Windows.Win32.Foundation.HRESULT = -2145124305
WU_E_INVALID_PROXY_SERVER: win32more.Windows.Win32.Foundation.HRESULT = -2145124304
WU_E_INVALID_FILE: win32more.Windows.Win32.Foundation.HRESULT = -2145124303
WU_E_INVALID_CRITERIA: win32more.Windows.Win32.Foundation.HRESULT = -2145124302
WU_E_EULA_UNAVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -2145124301
WU_E_DOWNLOAD_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2145124300
WU_E_UPDATE_NOT_PROCESSED: win32more.Windows.Win32.Foundation.HRESULT = -2145124299
WU_E_INVALID_OPERATION: win32more.Windows.Win32.Foundation.HRESULT = -2145124298
WU_E_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2145124297
WU_E_WINHTTP_INVALID_FILE: win32more.Windows.Win32.Foundation.HRESULT = -2145124296
WU_E_TOO_MANY_RESYNC: win32more.Windows.Win32.Foundation.HRESULT = -2145124295
WU_E_NO_SERVER_CORE_SUPPORT: win32more.Windows.Win32.Foundation.HRESULT = -2145124288
WU_E_SYSPREP_IN_PROGRESS: win32more.Windows.Win32.Foundation.HRESULT = -2145124287
WU_E_UNKNOWN_SERVICE: win32more.Windows.Win32.Foundation.HRESULT = -2145124286
WU_E_NO_UI_SUPPORT: win32more.Windows.Win32.Foundation.HRESULT = -2145124285
WU_E_PER_MACHINE_UPDATE_ACCESS_DENIED: win32more.Windows.Win32.Foundation.HRESULT = -2145124284
WU_E_UNSUPPORTED_SEARCHSCOPE: win32more.Windows.Win32.Foundation.HRESULT = -2145124283
WU_E_BAD_FILE_URL: win32more.Windows.Win32.Foundation.HRESULT = -2145124282
WU_E_REVERT_NOT_ALLOWED: win32more.Windows.Win32.Foundation.HRESULT = -2145124281
WU_E_INVALID_NOTIFICATION_INFO: win32more.Windows.Win32.Foundation.HRESULT = -2145124280
WU_E_OUTOFRANGE: win32more.Windows.Win32.Foundation.HRESULT = -2145124279
WU_E_SETUP_IN_PROGRESS: win32more.Windows.Win32.Foundation.HRESULT = -2145124278
WU_E_ORPHANED_DOWNLOAD_JOB: win32more.Windows.Win32.Foundation.HRESULT = -2145124277
WU_E_LOW_BATTERY: win32more.Windows.Win32.Foundation.HRESULT = -2145124276
WU_E_INFRASTRUCTUREFILE_INVALID_FORMAT: win32more.Windows.Win32.Foundation.HRESULT = -2145124275
WU_E_INFRASTRUCTUREFILE_REQUIRES_SSL: win32more.Windows.Win32.Foundation.HRESULT = -2145124274
WU_E_IDLESHUTDOWN_OPCOUNT_DISCOVERY: win32more.Windows.Win32.Foundation.HRESULT = -2145124273
WU_E_IDLESHUTDOWN_OPCOUNT_SEARCH: win32more.Windows.Win32.Foundation.HRESULT = -2145124272
WU_E_IDLESHUTDOWN_OPCOUNT_DOWNLOAD: win32more.Windows.Win32.Foundation.HRESULT = -2145124271
WU_E_IDLESHUTDOWN_OPCOUNT_INSTALL: win32more.Windows.Win32.Foundation.HRESULT = -2145124270
WU_E_IDLESHUTDOWN_OPCOUNT_OTHER: win32more.Windows.Win32.Foundation.HRESULT = -2145124269
WU_E_INTERACTIVE_CALL_CANCELLED: win32more.Windows.Win32.Foundation.HRESULT = -2145124268
WU_E_AU_CALL_CANCELLED: win32more.Windows.Win32.Foundation.HRESULT = -2145124267
WU_E_SYSTEM_UNSUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2145124266
WU_E_NO_SUCH_HANDLER_PLUGIN: win32more.Windows.Win32.Foundation.HRESULT = -2145124265
WU_E_INVALID_SERIALIZATION_VERSION: win32more.Windows.Win32.Foundation.HRESULT = -2145124264
WU_E_NETWORK_COST_EXCEEDS_POLICY: win32more.Windows.Win32.Foundation.HRESULT = -2145124263
WU_E_CALL_CANCELLED_BY_HIDE: win32more.Windows.Win32.Foundation.HRESULT = -2145124262
WU_E_CALL_CANCELLED_BY_INVALID: win32more.Windows.Win32.Foundation.HRESULT = -2145124261
WU_E_INVALID_VOLUMEID: win32more.Windows.Win32.Foundation.HRESULT = -2145124260
WU_E_UNRECOGNIZED_VOLUMEID: win32more.Windows.Win32.Foundation.HRESULT = -2145124259
WU_E_EXTENDEDERROR_NOTSET: win32more.Windows.Win32.Foundation.HRESULT = -2145124258
WU_E_EXTENDEDERROR_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2145124257
WU_E_IDLESHUTDOWN_OPCOUNT_SERVICEREGISTRATION: win32more.Windows.Win32.Foundation.HRESULT = -2145124256
WU_E_FILETRUST_SHA2SIGNATURE_MISSING: win32more.Windows.Win32.Foundation.HRESULT = -2145124255
WU_E_UPDATE_NOT_APPROVED: win32more.Windows.Win32.Foundation.HRESULT = -2145124254
WU_E_CALL_CANCELLED_BY_INTERACTIVE_SEARCH: win32more.Windows.Win32.Foundation.HRESULT = -2145124253
WU_E_INSTALL_JOB_RESUME_NOT_ALLOWED: win32more.Windows.Win32.Foundation.HRESULT = -2145124252
WU_E_INSTALL_JOB_NOT_SUSPENDED: win32more.Windows.Win32.Foundation.HRESULT = -2145124251
WU_E_INSTALL_USERCONTEXT_ACCESSDENIED: win32more.Windows.Win32.Foundation.HRESULT = -2145124250
WU_E_UNEXPECTED: win32more.Windows.Win32.Foundation.HRESULT = -2145120257
WU_E_MSI_WRONG_VERSION: win32more.Windows.Win32.Foundation.HRESULT = -2145120255
WU_E_MSI_NOT_CONFIGURED: win32more.Windows.Win32.Foundation.HRESULT = -2145120254
WU_E_MSP_DISABLED: win32more.Windows.Win32.Foundation.HRESULT = -2145120253
WU_E_MSI_WRONG_APP_CONTEXT: win32more.Windows.Win32.Foundation.HRESULT = -2145120252
WU_E_MSI_NOT_PRESENT: win32more.Windows.Win32.Foundation.HRESULT = -2145120251
WU_E_MSP_UNEXPECTED: win32more.Windows.Win32.Foundation.HRESULT = -2145116161
WU_E_PT_SOAPCLIENT_BASE: win32more.Windows.Win32.Foundation.HRESULT = -2145107968
WU_E_PT_SOAPCLIENT_INITIALIZE: win32more.Windows.Win32.Foundation.HRESULT = -2145107967
WU_E_PT_SOAPCLIENT_OUTOFMEMORY: win32more.Windows.Win32.Foundation.HRESULT = -2145107966
WU_E_PT_SOAPCLIENT_GENERATE: win32more.Windows.Win32.Foundation.HRESULT = -2145107965
WU_E_PT_SOAPCLIENT_CONNECT: win32more.Windows.Win32.Foundation.HRESULT = -2145107964
WU_E_PT_SOAPCLIENT_SEND: win32more.Windows.Win32.Foundation.HRESULT = -2145107963
WU_E_PT_SOAPCLIENT_SERVER: win32more.Windows.Win32.Foundation.HRESULT = -2145107962
WU_E_PT_SOAPCLIENT_SOAPFAULT: win32more.Windows.Win32.Foundation.HRESULT = -2145107961
WU_E_PT_SOAPCLIENT_PARSEFAULT: win32more.Windows.Win32.Foundation.HRESULT = -2145107960
WU_E_PT_SOAPCLIENT_READ: win32more.Windows.Win32.Foundation.HRESULT = -2145107959
WU_E_PT_SOAPCLIENT_PARSE: win32more.Windows.Win32.Foundation.HRESULT = -2145107958
WU_E_PT_SOAP_VERSION: win32more.Windows.Win32.Foundation.HRESULT = -2145107957
WU_E_PT_SOAP_MUST_UNDERSTAND: win32more.Windows.Win32.Foundation.HRESULT = -2145107956
WU_E_PT_SOAP_CLIENT: win32more.Windows.Win32.Foundation.HRESULT = -2145107955
WU_E_PT_SOAP_SERVER: win32more.Windows.Win32.Foundation.HRESULT = -2145107954
WU_E_PT_WMI_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2145107953
WU_E_PT_EXCEEDED_MAX_SERVER_TRIPS: win32more.Windows.Win32.Foundation.HRESULT = -2145107952
WU_E_PT_SUS_SERVER_NOT_SET: win32more.Windows.Win32.Foundation.HRESULT = -2145107951
WU_E_PT_DOUBLE_INITIALIZATION: win32more.Windows.Win32.Foundation.HRESULT = -2145107950
WU_E_PT_INVALID_COMPUTER_NAME: win32more.Windows.Win32.Foundation.HRESULT = -2145107949
WU_E_PT_REFRESH_CACHE_REQUIRED: win32more.Windows.Win32.Foundation.HRESULT = -2145107947
WU_E_PT_HTTP_STATUS_BAD_REQUEST: win32more.Windows.Win32.Foundation.HRESULT = -2145107946
WU_E_PT_HTTP_STATUS_DENIED: win32more.Windows.Win32.Foundation.HRESULT = -2145107945
WU_E_PT_HTTP_STATUS_FORBIDDEN: win32more.Windows.Win32.Foundation.HRESULT = -2145107944
WU_E_PT_HTTP_STATUS_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2145107943
WU_E_PT_HTTP_STATUS_BAD_METHOD: win32more.Windows.Win32.Foundation.HRESULT = -2145107942
WU_E_PT_HTTP_STATUS_PROXY_AUTH_REQ: win32more.Windows.Win32.Foundation.HRESULT = -2145107941
WU_E_PT_HTTP_STATUS_REQUEST_TIMEOUT: win32more.Windows.Win32.Foundation.HRESULT = -2145107940
WU_E_PT_HTTP_STATUS_CONFLICT: win32more.Windows.Win32.Foundation.HRESULT = -2145107939
WU_E_PT_HTTP_STATUS_GONE: win32more.Windows.Win32.Foundation.HRESULT = -2145107938
WU_E_PT_HTTP_STATUS_SERVER_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2145107937
WU_E_PT_HTTP_STATUS_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2145107936
WU_E_PT_HTTP_STATUS_BAD_GATEWAY: win32more.Windows.Win32.Foundation.HRESULT = -2145107935
WU_E_PT_HTTP_STATUS_SERVICE_UNAVAIL: win32more.Windows.Win32.Foundation.HRESULT = -2145107934
WU_E_PT_HTTP_STATUS_GATEWAY_TIMEOUT: win32more.Windows.Win32.Foundation.HRESULT = -2145107933
WU_E_PT_HTTP_STATUS_VERSION_NOT_SUP: win32more.Windows.Win32.Foundation.HRESULT = -2145107932
WU_E_PT_FILE_LOCATIONS_CHANGED: win32more.Windows.Win32.Foundation.HRESULT = -2145107931
WU_E_PT_REGISTRATION_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2145107930
WU_E_PT_NO_AUTH_PLUGINS_REQUESTED: win32more.Windows.Win32.Foundation.HRESULT = -2145107929
WU_E_PT_NO_AUTH_COOKIES_CREATED: win32more.Windows.Win32.Foundation.HRESULT = -2145107928
WU_E_PT_INVALID_CONFIG_PROP: win32more.Windows.Win32.Foundation.HRESULT = -2145107927
WU_E_PT_CONFIG_PROP_MISSING: win32more.Windows.Win32.Foundation.HRESULT = -2145107926
WU_E_PT_HTTP_STATUS_NOT_MAPPED: win32more.Windows.Win32.Foundation.HRESULT = -2145107925
WU_E_PT_WINHTTP_NAME_NOT_RESOLVED: win32more.Windows.Win32.Foundation.HRESULT = -2145107924
WU_E_PT_LOAD_SHEDDING: win32more.Windows.Win32.Foundation.HRESULT = -2145107923
WU_E_PT_SAME_REDIR_ID: win32more.Windows.Win32.Foundation.HRESULT = -2145103827
WU_E_PT_NO_MANAGED_RECOVER: win32more.Windows.Win32.Foundation.HRESULT = -2145103826
WU_E_PT_ECP_SUCCEEDED_WITH_ERRORS: win32more.Windows.Win32.Foundation.HRESULT = -2145107921
WU_E_PT_ECP_INIT_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2145107920
WU_E_PT_ECP_INVALID_FILE_FORMAT: win32more.Windows.Win32.Foundation.HRESULT = -2145107919
WU_E_PT_ECP_INVALID_METADATA: win32more.Windows.Win32.Foundation.HRESULT = -2145107918
WU_E_PT_ECP_FAILURE_TO_EXTRACT_DIGEST: win32more.Windows.Win32.Foundation.HRESULT = -2145107917
WU_E_PT_ECP_FAILURE_TO_DECOMPRESS_CAB_FILE: win32more.Windows.Win32.Foundation.HRESULT = -2145107916
WU_E_PT_ECP_FILE_LOCATION_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2145107915
WU_E_PT_CATALOG_SYNC_REQUIRED: win32more.Windows.Win32.Foundation.HRESULT = -2145123274
WU_E_PT_SECURITY_VERIFICATION_FAILURE: win32more.Windows.Win32.Foundation.HRESULT = -2145123273
WU_E_PT_ENDPOINT_UNREACHABLE: win32more.Windows.Win32.Foundation.HRESULT = -2145123272
WU_E_PT_INVALID_FORMAT: win32more.Windows.Win32.Foundation.HRESULT = -2145123271
WU_E_PT_INVALID_URL: win32more.Windows.Win32.Foundation.HRESULT = -2145123270
WU_E_PT_NWS_NOT_LOADED: win32more.Windows.Win32.Foundation.HRESULT = -2145123269
WU_E_PT_PROXY_AUTH_SCHEME_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2145123268
WU_E_SERVICEPROP_NOTAVAIL: win32more.Windows.Win32.Foundation.HRESULT = -2145123267
WU_E_PT_ENDPOINT_REFRESH_REQUIRED: win32more.Windows.Win32.Foundation.HRESULT = -2145123266
WU_E_PT_ENDPOINTURL_NOTAVAIL: win32more.Windows.Win32.Foundation.HRESULT = -2145123265
WU_E_PT_ENDPOINT_DISCONNECTED: win32more.Windows.Win32.Foundation.HRESULT = -2145123264
WU_E_PT_INVALID_OPERATION: win32more.Windows.Win32.Foundation.HRESULT = -2145123263
WU_E_PT_OBJECT_FAULTED: win32more.Windows.Win32.Foundation.HRESULT = -2145123262
WU_E_PT_NUMERIC_OVERFLOW: win32more.Windows.Win32.Foundation.HRESULT = -2145123261
WU_E_PT_OPERATION_ABORTED: win32more.Windows.Win32.Foundation.HRESULT = -2145123260
WU_E_PT_OPERATION_ABANDONED: win32more.Windows.Win32.Foundation.HRESULT = -2145123259
WU_E_PT_QUOTA_EXCEEDED: win32more.Windows.Win32.Foundation.HRESULT = -2145123258
WU_E_PT_NO_TRANSLATION_AVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -2145123257
WU_E_PT_ADDRESS_IN_USE: win32more.Windows.Win32.Foundation.HRESULT = -2145123256
WU_E_PT_ADDRESS_NOT_AVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -2145123255
WU_E_PT_OTHER: win32more.Windows.Win32.Foundation.HRESULT = -2145123254
WU_E_PT_SECURITY_SYSTEM_FAILURE: win32more.Windows.Win32.Foundation.HRESULT = -2145123253
WU_E_PT_DATA_BOUNDARY_RESTRICTED: win32more.Windows.Win32.Foundation.HRESULT = -2145107712
WU_E_PT_GENERAL_AAD_CLIENT_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2145107711
WU_E_PT_UNEXPECTED: win32more.Windows.Win32.Foundation.HRESULT = -2145103873
WU_E_REDIRECTOR_LOAD_XML: win32more.Windows.Win32.Foundation.HRESULT = -2145103871
WU_E_REDIRECTOR_S_FALSE: win32more.Windows.Win32.Foundation.HRESULT = -2145103870
WU_E_REDIRECTOR_ID_SMALLER: win32more.Windows.Win32.Foundation.HRESULT = -2145103869
WU_E_REDIRECTOR_UNKNOWN_SERVICE: win32more.Windows.Win32.Foundation.HRESULT = -2145103868
WU_E_REDIRECTOR_UNSUPPORTED_CONTENTTYPE: win32more.Windows.Win32.Foundation.HRESULT = -2145103867
WU_E_REDIRECTOR_INVALID_RESPONSE: win32more.Windows.Win32.Foundation.HRESULT = -2145103866
WU_E_REDIRECTOR_ATTRPROVIDER_EXCEEDED_MAX_NAMEVALUE: win32more.Windows.Win32.Foundation.HRESULT = -2145103864
WU_E_REDIRECTOR_ATTRPROVIDER_INVALID_NAME: win32more.Windows.Win32.Foundation.HRESULT = -2145103863
WU_E_REDIRECTOR_ATTRPROVIDER_INVALID_VALUE: win32more.Windows.Win32.Foundation.HRESULT = -2145103862
WU_E_REDIRECTOR_SLS_GENERIC_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2145103861
WU_E_REDIRECTOR_CONNECT_POLICY: win32more.Windows.Win32.Foundation.HRESULT = -2145103860
WU_E_REDIRECTOR_ONLINE_DISALLOWED: win32more.Windows.Win32.Foundation.HRESULT = -2145103859
WU_E_REDIRECTOR_UNEXPECTED: win32more.Windows.Win32.Foundation.HRESULT = -2145103617
WU_E_SIH_VERIFY_DOWNLOAD_ENGINE: win32more.Windows.Win32.Foundation.HRESULT = -2145103615
WU_E_SIH_VERIFY_DOWNLOAD_PAYLOAD: win32more.Windows.Win32.Foundation.HRESULT = -2145103614
WU_E_SIH_VERIFY_STAGE_ENGINE: win32more.Windows.Win32.Foundation.HRESULT = -2145103613
WU_E_SIH_VERIFY_STAGE_PAYLOAD: win32more.Windows.Win32.Foundation.HRESULT = -2145103612
WU_E_SIH_ACTION_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2145103611
WU_E_SIH_SLS_PARSE: win32more.Windows.Win32.Foundation.HRESULT = -2145103610
WU_E_SIH_INVALIDHASH: win32more.Windows.Win32.Foundation.HRESULT = -2145103609
WU_E_SIH_NO_ENGINE: win32more.Windows.Win32.Foundation.HRESULT = -2145103608
WU_E_SIH_POST_REBOOT_INSTALL_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2145103607
WU_E_SIH_POST_REBOOT_NO_CACHED_SLS_RESPONSE: win32more.Windows.Win32.Foundation.HRESULT = -2145103606
WU_E_SIH_PARSE: win32more.Windows.Win32.Foundation.HRESULT = -2145103605
WU_E_SIH_SECURITY: win32more.Windows.Win32.Foundation.HRESULT = -2145103604
WU_E_SIH_PPL: win32more.Windows.Win32.Foundation.HRESULT = -2145103603
WU_E_SIH_POLICY: win32more.Windows.Win32.Foundation.HRESULT = -2145103602
WU_E_SIH_STDEXCEPTION: win32more.Windows.Win32.Foundation.HRESULT = -2145103601
WU_E_SIH_NONSTDEXCEPTION: win32more.Windows.Win32.Foundation.HRESULT = -2145103600
WU_E_SIH_ENGINE_EXCEPTION: win32more.Windows.Win32.Foundation.HRESULT = -2145103599
WU_E_SIH_BLOCKED_FOR_PLATFORM: win32more.Windows.Win32.Foundation.HRESULT = -2145103598
WU_E_SIH_ANOTHER_INSTANCE_RUNNING: win32more.Windows.Win32.Foundation.HRESULT = -2145103597
WU_E_SIH_DNSRESILIENCY_OFF: win32more.Windows.Win32.Foundation.HRESULT = -2145103596
WU_E_SIH_UNEXPECTED: win32more.Windows.Win32.Foundation.HRESULT = -2145103361
WU_E_DRV_PRUNED: win32more.Windows.Win32.Foundation.HRESULT = -2145075199
WU_E_DRV_NOPROP_OR_LEGACY: win32more.Windows.Win32.Foundation.HRESULT = -2145075198
WU_E_DRV_REG_MISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -2145075197
WU_E_DRV_NO_METADATA: win32more.Windows.Win32.Foundation.HRESULT = -2145075196
WU_E_DRV_MISSING_ATTRIBUTE: win32more.Windows.Win32.Foundation.HRESULT = -2145075195
WU_E_DRV_SYNC_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2145075194
WU_E_DRV_NO_PRINTER_CONTENT: win32more.Windows.Win32.Foundation.HRESULT = -2145075193
WU_E_DRV_DEVICE_PROBLEM: win32more.Windows.Win32.Foundation.HRESULT = -2145075192
WU_E_DRV_UNEXPECTED: win32more.Windows.Win32.Foundation.HRESULT = -2145071105
WU_E_DS_SHUTDOWN: win32more.Windows.Win32.Foundation.HRESULT = -2145091584
WU_E_DS_INUSE: win32more.Windows.Win32.Foundation.HRESULT = -2145091583
WU_E_DS_INVALID: win32more.Windows.Win32.Foundation.HRESULT = -2145091582
WU_E_DS_TABLEMISSING: win32more.Windows.Win32.Foundation.HRESULT = -2145091581
WU_E_DS_TABLEINCORRECT: win32more.Windows.Win32.Foundation.HRESULT = -2145091580
WU_E_DS_INVALIDTABLENAME: win32more.Windows.Win32.Foundation.HRESULT = -2145091579
WU_E_DS_BADVERSION: win32more.Windows.Win32.Foundation.HRESULT = -2145091578
WU_E_DS_NODATA: win32more.Windows.Win32.Foundation.HRESULT = -2145091577
WU_E_DS_MISSINGDATA: win32more.Windows.Win32.Foundation.HRESULT = -2145091576
WU_E_DS_MISSINGREF: win32more.Windows.Win32.Foundation.HRESULT = -2145091575
WU_E_DS_UNKNOWNHANDLER: win32more.Windows.Win32.Foundation.HRESULT = -2145091574
WU_E_DS_CANTDELETE: win32more.Windows.Win32.Foundation.HRESULT = -2145091573
WU_E_DS_LOCKTIMEOUTEXPIRED: win32more.Windows.Win32.Foundation.HRESULT = -2145091572
WU_E_DS_NOCATEGORIES: win32more.Windows.Win32.Foundation.HRESULT = -2145091571
WU_E_DS_ROWEXISTS: win32more.Windows.Win32.Foundation.HRESULT = -2145091570
WU_E_DS_STOREFILELOCKED: win32more.Windows.Win32.Foundation.HRESULT = -2145091569
WU_E_DS_CANNOTREGISTER: win32more.Windows.Win32.Foundation.HRESULT = -2145091568
WU_E_DS_UNABLETOSTART: win32more.Windows.Win32.Foundation.HRESULT = -2145091567
WU_E_DS_DUPLICATEUPDATEID: win32more.Windows.Win32.Foundation.HRESULT = -2145091565
WU_E_DS_UNKNOWNSERVICE: win32more.Windows.Win32.Foundation.HRESULT = -2145091564
WU_E_DS_SERVICEEXPIRED: win32more.Windows.Win32.Foundation.HRESULT = -2145091563
WU_E_DS_DECLINENOTALLOWED: win32more.Windows.Win32.Foundation.HRESULT = -2145091562
WU_E_DS_TABLESESSIONMISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -2145091561
WU_E_DS_SESSIONLOCKMISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -2145091560
WU_E_DS_NEEDWINDOWSSERVICE: win32more.Windows.Win32.Foundation.HRESULT = -2145091559
WU_E_DS_INVALIDOPERATION: win32more.Windows.Win32.Foundation.HRESULT = -2145091558
WU_E_DS_SCHEMAMISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -2145091557
WU_E_DS_RESETREQUIRED: win32more.Windows.Win32.Foundation.HRESULT = -2145091556
WU_E_DS_IMPERSONATED: win32more.Windows.Win32.Foundation.HRESULT = -2145091555
WU_E_DS_DATANOTAVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -2145091554
WU_E_DS_DATANOTLOADED: win32more.Windows.Win32.Foundation.HRESULT = -2145091553
WU_E_DS_NODATA_NOSUCHREVISION: win32more.Windows.Win32.Foundation.HRESULT = -2145091552
WU_E_DS_NODATA_NOSUCHUPDATE: win32more.Windows.Win32.Foundation.HRESULT = -2145091551
WU_E_DS_NODATA_EULA: win32more.Windows.Win32.Foundation.HRESULT = -2145091550
WU_E_DS_NODATA_SERVICE: win32more.Windows.Win32.Foundation.HRESULT = -2145091549
WU_E_DS_NODATA_COOKIE: win32more.Windows.Win32.Foundation.HRESULT = -2145091548
WU_E_DS_NODATA_TIMER: win32more.Windows.Win32.Foundation.HRESULT = -2145091547
WU_E_DS_NODATA_CCR: win32more.Windows.Win32.Foundation.HRESULT = -2145091546
WU_E_DS_NODATA_FILE: win32more.Windows.Win32.Foundation.HRESULT = -2145091545
WU_E_DS_NODATA_DOWNLOADJOB: win32more.Windows.Win32.Foundation.HRESULT = -2145091544
WU_E_DS_NODATA_TMI: win32more.Windows.Win32.Foundation.HRESULT = -2145091543
WU_E_DS_UNEXPECTED: win32more.Windows.Win32.Foundation.HRESULT = -2145087489
WU_E_INVENTORY_PARSEFAILED: win32more.Windows.Win32.Foundation.HRESULT = -2145087487
WU_E_INVENTORY_GET_INVENTORY_TYPE_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2145087486
WU_E_INVENTORY_RESULT_UPLOAD_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2145087485
WU_E_INVENTORY_UNEXPECTED: win32more.Windows.Win32.Foundation.HRESULT = -2145087484
WU_E_INVENTORY_WMI_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2145087483
WU_E_AU_NOSERVICE: win32more.Windows.Win32.Foundation.HRESULT = -2145083392
WU_E_AU_NONLEGACYSERVER: win32more.Windows.Win32.Foundation.HRESULT = -2145083390
WU_E_AU_LEGACYCLIENTDISABLED: win32more.Windows.Win32.Foundation.HRESULT = -2145083389
WU_E_AU_PAUSED: win32more.Windows.Win32.Foundation.HRESULT = -2145083388
WU_E_AU_NO_REGISTERED_SERVICE: win32more.Windows.Win32.Foundation.HRESULT = -2145083387
WU_E_AU_DETECT_SVCID_MISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -2145083386
WU_E_REBOOT_IN_PROGRESS: win32more.Windows.Win32.Foundation.HRESULT = -2145083385
WU_E_AU_OOBE_IN_PROGRESS: win32more.Windows.Win32.Foundation.HRESULT = -2145083384
WU_E_AU_UNEXPECTED: win32more.Windows.Win32.Foundation.HRESULT = -2145079297
WU_E_UH_REMOTEUNAVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -2145116160
WU_E_UH_LOCALONLY: win32more.Windows.Win32.Foundation.HRESULT = -2145116159
WU_E_UH_UNKNOWNHANDLER: win32more.Windows.Win32.Foundation.HRESULT = -2145116158
WU_E_UH_REMOTEALREADYACTIVE: win32more.Windows.Win32.Foundation.HRESULT = -2145116157
WU_E_UH_DOESNOTSUPPORTACTION: win32more.Windows.Win32.Foundation.HRESULT = -2145116156
WU_E_UH_WRONGHANDLER: win32more.Windows.Win32.Foundation.HRESULT = -2145116155
WU_E_UH_INVALIDMETADATA: win32more.Windows.Win32.Foundation.HRESULT = -2145116154
WU_E_UH_INSTALLERHUNG: win32more.Windows.Win32.Foundation.HRESULT = -2145116153
WU_E_UH_OPERATIONCANCELLED: win32more.Windows.Win32.Foundation.HRESULT = -2145116152
WU_E_UH_BADHANDLERXML: win32more.Windows.Win32.Foundation.HRESULT = -2145116151
WU_E_UH_CANREQUIREINPUT: win32more.Windows.Win32.Foundation.HRESULT = -2145116150
WU_E_UH_INSTALLERFAILURE: win32more.Windows.Win32.Foundation.HRESULT = -2145116149
WU_E_UH_FALLBACKTOSELFCONTAINED: win32more.Windows.Win32.Foundation.HRESULT = -2145116148
WU_E_UH_NEEDANOTHERDOWNLOAD: win32more.Windows.Win32.Foundation.HRESULT = -2145116147
WU_E_UH_NOTIFYFAILURE: win32more.Windows.Win32.Foundation.HRESULT = -2145116146
WU_E_UH_INCONSISTENT_FILE_NAMES: win32more.Windows.Win32.Foundation.HRESULT = -2145116145
WU_E_UH_FALLBACKERROR: win32more.Windows.Win32.Foundation.HRESULT = -2145116144
WU_E_UH_TOOMANYDOWNLOADREQUESTS: win32more.Windows.Win32.Foundation.HRESULT = -2145116143
WU_E_UH_UNEXPECTEDCBSRESPONSE: win32more.Windows.Win32.Foundation.HRESULT = -2145116142
WU_E_UH_BADCBSPACKAGEID: win32more.Windows.Win32.Foundation.HRESULT = -2145116141
WU_E_UH_POSTREBOOTSTILLPENDING: win32more.Windows.Win32.Foundation.HRESULT = -2145116140
WU_E_UH_POSTREBOOTRESULTUNKNOWN: win32more.Windows.Win32.Foundation.HRESULT = -2145116139
WU_E_UH_POSTREBOOTUNEXPECTEDSTATE: win32more.Windows.Win32.Foundation.HRESULT = -2145116138
WU_E_UH_NEW_SERVICING_STACK_REQUIRED: win32more.Windows.Win32.Foundation.HRESULT = -2145116137
WU_E_UH_CALLED_BACK_FAILURE: win32more.Windows.Win32.Foundation.HRESULT = -2145116136
WU_E_UH_CUSTOMINSTALLER_INVALID_SIGNATURE: win32more.Windows.Win32.Foundation.HRESULT = -2145116135
WU_E_UH_UNSUPPORTED_INSTALLCONTEXT: win32more.Windows.Win32.Foundation.HRESULT = -2145116134
WU_E_UH_INVALID_TARGETSESSION: win32more.Windows.Win32.Foundation.HRESULT = -2145116133
WU_E_UH_DECRYPTFAILURE: win32more.Windows.Win32.Foundation.HRESULT = -2145116132
WU_E_UH_HANDLER_DISABLEDUNTILREBOOT: win32more.Windows.Win32.Foundation.HRESULT = -2145116131
WU_E_UH_APPX_NOT_PRESENT: win32more.Windows.Win32.Foundation.HRESULT = -2145116130
WU_E_UH_NOTREADYTOCOMMIT: win32more.Windows.Win32.Foundation.HRESULT = -2145116129
WU_E_UH_APPX_INVALID_PACKAGE_VOLUME: win32more.Windows.Win32.Foundation.HRESULT = -2145116128
WU_E_UH_APPX_DEFAULT_PACKAGE_VOLUME_UNAVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -2145116127
WU_E_UH_APPX_INSTALLED_PACKAGE_VOLUME_UNAVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -2145116126
WU_E_UH_APPX_PACKAGE_FAMILY_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2145116125
WU_E_UH_APPX_SYSTEM_VOLUME_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2145116124
WU_E_UH_UNEXPECTED: win32more.Windows.Win32.Foundation.HRESULT = -2145112065
WU_E_DM_URLNOTAVAILABLE: win32more.Windows.Win32.Foundation.HRESULT = -2145099775
WU_E_DM_INCORRECTFILEHASH: win32more.Windows.Win32.Foundation.HRESULT = -2145099774
WU_E_DM_UNKNOWNALGORITHM: win32more.Windows.Win32.Foundation.HRESULT = -2145099773
WU_E_DM_NEEDDOWNLOADREQUEST: win32more.Windows.Win32.Foundation.HRESULT = -2145099772
WU_E_DM_NONETWORK: win32more.Windows.Win32.Foundation.HRESULT = -2145099771
WU_E_DM_WRONGBITSVERSION: win32more.Windows.Win32.Foundation.HRESULT = -2145099770
WU_E_DM_NOTDOWNLOADED: win32more.Windows.Win32.Foundation.HRESULT = -2145099769
WU_E_DM_FAILTOCONNECTTOBITS: win32more.Windows.Win32.Foundation.HRESULT = -2145099768
WU_E_DM_BITSTRANSFERERROR: win32more.Windows.Win32.Foundation.HRESULT = -2145099767
WU_E_DM_DOWNLOADLOCATIONCHANGED: win32more.Windows.Win32.Foundation.HRESULT = -2145099766
WU_E_DM_CONTENTCHANGED: win32more.Windows.Win32.Foundation.HRESULT = -2145099765
WU_E_DM_DOWNLOADLIMITEDBYUPDATESIZE: win32more.Windows.Win32.Foundation.HRESULT = -2145099764
WU_E_DM_UNAUTHORIZED: win32more.Windows.Win32.Foundation.HRESULT = -2145099762
WU_E_DM_BG_ERROR_TOKEN_REQUIRED: win32more.Windows.Win32.Foundation.HRESULT = -2145099761
WU_E_DM_DOWNLOADSANDBOXNOTFOUND: win32more.Windows.Win32.Foundation.HRESULT = -2145099760
WU_E_DM_DOWNLOADFILEPATHUNKNOWN: win32more.Windows.Win32.Foundation.HRESULT = -2145099759
WU_E_DM_DOWNLOADFILEMISSING: win32more.Windows.Win32.Foundation.HRESULT = -2145099758
WU_E_DM_UPDATEREMOVED: win32more.Windows.Win32.Foundation.HRESULT = -2145099757
WU_E_DM_READRANGEFAILED: win32more.Windows.Win32.Foundation.HRESULT = -2145099756
WU_E_DM_UNAUTHORIZED_NO_USER: win32more.Windows.Win32.Foundation.HRESULT = -2145099754
WU_E_DM_UNAUTHORIZED_LOCAL_USER: win32more.Windows.Win32.Foundation.HRESULT = -2145099753
WU_E_DM_UNAUTHORIZED_DOMAIN_USER: win32more.Windows.Win32.Foundation.HRESULT = -2145099752
WU_E_DM_UNAUTHORIZED_MSA_USER: win32more.Windows.Win32.Foundation.HRESULT = -2145099751
WU_E_DM_FALLINGBACKTOBITS: win32more.Windows.Win32.Foundation.HRESULT = -2145099750
WU_E_DM_DOWNLOAD_VOLUME_CONFLICT: win32more.Windows.Win32.Foundation.HRESULT = -2145099749
WU_E_DM_SANDBOX_HASH_MISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -2145099748
WU_E_DM_HARDRESERVEID_CONFLICT: win32more.Windows.Win32.Foundation.HRESULT = -2145099747
WU_E_DM_DOSVC_REQUIRED: win32more.Windows.Win32.Foundation.HRESULT = -2145099746
WU_E_DM_UNEXPECTED: win32more.Windows.Win32.Foundation.HRESULT = -2145095681
WU_E_SETUP_INVALID_INFDATA: win32more.Windows.Win32.Foundation.HRESULT = -2145071103
WU_E_SETUP_INVALID_IDENTDATA: win32more.Windows.Win32.Foundation.HRESULT = -2145071102
WU_E_SETUP_ALREADY_INITIALIZED: win32more.Windows.Win32.Foundation.HRESULT = -2145071101
WU_E_SETUP_NOT_INITIALIZED: win32more.Windows.Win32.Foundation.HRESULT = -2145071100
WU_E_SETUP_SOURCE_VERSION_MISMATCH: win32more.Windows.Win32.Foundation.HRESULT = -2145071099
WU_E_SETUP_TARGET_VERSION_GREATER: win32more.Windows.Win32.Foundation.HRESULT = -2145071098
WU_E_SETUP_REGISTRATION_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2145071097
WU_E_SELFUPDATE_SKIP_ON_FAILURE: win32more.Windows.Win32.Foundation.HRESULT = -2145071096
WU_E_SETUP_SKIP_UPDATE: win32more.Windows.Win32.Foundation.HRESULT = -2145071095
WU_E_SETUP_UNSUPPORTED_CONFIGURATION: win32more.Windows.Win32.Foundation.HRESULT = -2145071094
WU_E_SETUP_BLOCKED_CONFIGURATION: win32more.Windows.Win32.Foundation.HRESULT = -2145071093
WU_E_SETUP_REBOOT_TO_FIX: win32more.Windows.Win32.Foundation.HRESULT = -2145071092
WU_E_SETUP_ALREADYRUNNING: win32more.Windows.Win32.Foundation.HRESULT = -2145071091
WU_E_SETUP_REBOOTREQUIRED: win32more.Windows.Win32.Foundation.HRESULT = -2145071090
WU_E_SETUP_HANDLER_EXEC_FAILURE: win32more.Windows.Win32.Foundation.HRESULT = -2145071089
WU_E_SETUP_INVALID_REGISTRY_DATA: win32more.Windows.Win32.Foundation.HRESULT = -2145071088
WU_E_SELFUPDATE_REQUIRED: win32more.Windows.Win32.Foundation.HRESULT = -2145071087
WU_E_SELFUPDATE_REQUIRED_ADMIN: win32more.Windows.Win32.Foundation.HRESULT = -2145071086
WU_E_SETUP_WRONG_SERVER_VERSION: win32more.Windows.Win32.Foundation.HRESULT = -2145071085
WU_E_SETUP_DEFERRABLE_REBOOT_PENDING: win32more.Windows.Win32.Foundation.HRESULT = -2145071084
WU_E_SETUP_NON_DEFERRABLE_REBOOT_PENDING: win32more.Windows.Win32.Foundation.HRESULT = -2145071083
WU_E_SETUP_FAIL: win32more.Windows.Win32.Foundation.HRESULT = -2145071082
WU_E_SETUP_UNEXPECTED: win32more.Windows.Win32.Foundation.HRESULT = -2145067009
WU_E_EE_UNKNOWN_EXPRESSION: win32more.Windows.Win32.Foundation.HRESULT = -2145067007
WU_E_EE_INVALID_EXPRESSION: win32more.Windows.Win32.Foundation.HRESULT = -2145067006
WU_E_EE_MISSING_METADATA: win32more.Windows.Win32.Foundation.HRESULT = -2145067005
WU_E_EE_INVALID_VERSION: win32more.Windows.Win32.Foundation.HRESULT = -2145067004
WU_E_EE_NOT_INITIALIZED: win32more.Windows.Win32.Foundation.HRESULT = -2145067003
WU_E_EE_INVALID_ATTRIBUTEDATA: win32more.Windows.Win32.Foundation.HRESULT = -2145067002
WU_E_EE_CLUSTER_ERROR: win32more.Windows.Win32.Foundation.HRESULT = -2145067001
WU_E_EE_UNEXPECTED: win32more.Windows.Win32.Foundation.HRESULT = -2145062913
WU_E_INSTALLATION_RESULTS_UNKNOWN_VERSION: win32more.Windows.Win32.Foundation.HRESULT = -2145112063
WU_E_INSTALLATION_RESULTS_INVALID_DATA: win32more.Windows.Win32.Foundation.HRESULT = -2145112062
WU_E_INSTALLATION_RESULTS_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2145112061
WU_E_TRAYICON_FAILURE: win32more.Windows.Win32.Foundation.HRESULT = -2145112060
WU_E_NON_UI_MODE: win32more.Windows.Win32.Foundation.HRESULT = -2145107971
WU_E_WUCLTUI_UNSUPPORTED_VERSION: win32more.Windows.Win32.Foundation.HRESULT = -2145107970
WU_E_AUCLIENT_UNEXPECTED: win32more.Windows.Win32.Foundation.HRESULT = -2145107969
WU_E_REPORTER_EVENTCACHECORRUPT: win32more.Windows.Win32.Foundation.HRESULT = -2145062911
WU_E_REPORTER_EVENTNAMESPACEPARSEFAILED: win32more.Windows.Win32.Foundation.HRESULT = -2145062910
WU_E_INVALID_EVENT: win32more.Windows.Win32.Foundation.HRESULT = -2145062909
WU_E_SERVER_BUSY: win32more.Windows.Win32.Foundation.HRESULT = -2145062908
WU_E_CALLBACK_COOKIE_NOT_FOUND: win32more.Windows.Win32.Foundation.HRESULT = -2145062907
WU_E_REPORTER_UNEXPECTED: win32more.Windows.Win32.Foundation.HRESULT = -2145058817
WU_E_OL_INVALID_SCANFILE: win32more.Windows.Win32.Foundation.HRESULT = -2145095679
WU_E_OL_NEWCLIENT_REQUIRED: win32more.Windows.Win32.Foundation.HRESULT = -2145095678
WU_E_INVALID_EVENT_PAYLOAD: win32more.Windows.Win32.Foundation.HRESULT = -2145095677
WU_E_INVALID_EVENT_PAYLOADSIZE: win32more.Windows.Win32.Foundation.HRESULT = -2145095676
WU_E_SERVICE_NOT_REGISTERED: win32more.Windows.Win32.Foundation.HRESULT = -2145095675
WU_E_OL_UNEXPECTED: win32more.Windows.Win32.Foundation.HRESULT = -2145091585
WU_E_METADATA_NOOP: win32more.Windows.Win32.Foundation.HRESULT = -2145095424
WU_E_METADATA_CONFIG_INVALID_BINARY_ENCODING: win32more.Windows.Win32.Foundation.HRESULT = -2145095423
WU_E_METADATA_FETCH_CONFIG: win32more.Windows.Win32.Foundation.HRESULT = -2145095422
WU_E_METADATA_INVALID_PARAMETER: win32more.Windows.Win32.Foundation.HRESULT = -2145095420
WU_E_METADATA_UNEXPECTED: win32more.Windows.Win32.Foundation.HRESULT = -2145095419
WU_E_METADATA_NO_VERIFICATION_DATA: win32more.Windows.Win32.Foundation.HRESULT = -2145095418
WU_E_METADATA_BAD_FRAGMENTSIGNING_CONFIG: win32more.Windows.Win32.Foundation.HRESULT = -2145095417
WU_E_METADATA_FAILURE_PROCESSING_FRAGMENTSIGNING_CONFIG: win32more.Windows.Win32.Foundation.HRESULT = -2145095416
WU_E_METADATA_XML_MISSING: win32more.Windows.Win32.Foundation.HRESULT = -2145095392
WU_E_METADATA_XML_FRAGMENTSIGNING_MISSING: win32more.Windows.Win32.Foundation.HRESULT = -2145095391
WU_E_METADATA_XML_MODE_MISSING: win32more.Windows.Win32.Foundation.HRESULT = -2145095390
WU_E_METADATA_XML_MODE_INVALID: win32more.Windows.Win32.Foundation.HRESULT = -2145095389
WU_E_METADATA_XML_VALIDITY_INVALID: win32more.Windows.Win32.Foundation.HRESULT = -2145095388
WU_E_METADATA_XML_LEAFCERT_MISSING: win32more.Windows.Win32.Foundation.HRESULT = -2145095387
WU_E_METADATA_XML_INTERMEDIATECERT_MISSING: win32more.Windows.Win32.Foundation.HRESULT = -2145095386
WU_E_METADATA_XML_LEAFCERT_ID_MISSING: win32more.Windows.Win32.Foundation.HRESULT = -2145095385
WU_E_METADATA_XML_BASE64CERDATA_MISSING: win32more.Windows.Win32.Foundation.HRESULT = -2145095384
WU_E_METADATA_BAD_SIGNATURE: win32more.Windows.Win32.Foundation.HRESULT = -2145095360
WU_E_METADATA_UNSUPPORTED_HASH_ALG: win32more.Windows.Win32.Foundation.HRESULT = -2145095359
WU_E_METADATA_SIGNATURE_VERIFY_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2145095358
WU_E_METADATATRUST_CERTIFICATECHAIN_VERIFICATION: win32more.Windows.Win32.Foundation.HRESULT = -2145095344
WU_E_METADATATRUST_UNTRUSTED_CERTIFICATECHAIN: win32more.Windows.Win32.Foundation.HRESULT = -2145095343
WU_E_METADATA_TIMESTAMP_TOKEN_MISSING: win32more.Windows.Win32.Foundation.HRESULT = -2145095328
WU_E_METADATA_TIMESTAMP_TOKEN_VERIFICATION_FAILED: win32more.Windows.Win32.Foundation.HRESULT = -2145095327
WU_E_METADATA_TIMESTAMP_TOKEN_UNTRUSTED: win32more.Windows.Win32.Foundation.HRESULT = -2145095326
WU_E_METADATA_TIMESTAMP_TOKEN_VALIDITY_WINDOW: win32more.Windows.Win32.Foundation.HRESULT = -2145095325
WU_E_METADATA_TIMESTAMP_TOKEN_SIGNATURE: win32more.Windows.Win32.Foundation.HRESULT = -2145095324
WU_E_METADATA_TIMESTAMP_TOKEN_CERTCHAIN: win32more.Windows.Win32.Foundation.HRESULT = -2145095323
WU_E_METADATA_TIMESTAMP_TOKEN_REFRESHONLINE: win32more.Windows.Win32.Foundation.HRESULT = -2145095322
WU_E_METADATA_TIMESTAMP_TOKEN_ALL_BAD: win32more.Windows.Win32.Foundation.HRESULT = -2145095321
WU_E_METADATA_TIMESTAMP_TOKEN_NODATA: win32more.Windows.Win32.Foundation.HRESULT = -2145095320
WU_E_METADATA_TIMESTAMP_TOKEN_CACHELOOKUP: win32more.Windows.Win32.Foundation.HRESULT = -2145095319
WU_E_METADATA_TIMESTAMP_TOKEN_VALIDITYWINDOW_UNEXPECTED: win32more.Windows.Win32.Foundation.HRESULT = -2145095298
WU_E_METADATA_TIMESTAMP_TOKEN_UNEXPECTED: win32more.Windows.Win32.Foundation.HRESULT = -2145095297
WU_E_METADATA_CERT_MISSING: win32more.Windows.Win32.Foundation.HRESULT = -2145095296
WU_E_METADATA_LEAFCERT_BAD_TRANSPORT_ENCODING: win32more.Windows.Win32.Foundation.HRESULT = -2145095295
WU_E_METADATA_INTCERT_BAD_TRANSPORT_ENCODING: win32more.Windows.Win32.Foundation.HRESULT = -2145095294
WU_E_METADATA_CERT_UNTRUSTED: win32more.Windows.Win32.Foundation.HRESULT = -2145095293
WU_E_WUTASK_INPROGRESS: win32more.Windows.Win32.Foundation.HRESULT = -2145079295
WU_E_WUTASK_STATUS_DISABLED: win32more.Windows.Win32.Foundation.HRESULT = -2145079294
WU_E_WUTASK_NOT_STARTED: win32more.Windows.Win32.Foundation.HRESULT = -2145079293
WU_E_WUTASK_RETRY: win32more.Windows.Win32.Foundation.HRESULT = -2145079292
WU_E_WUTASK_CANCELINSTALL_DISALLOWED: win32more.Windows.Win32.Foundation.HRESULT = -2145079291
WU_E_UNKNOWN_HARDWARECAPABILITY: win32more.Windows.Win32.Foundation.HRESULT = -2145079039
WU_E_BAD_XML_HARDWARECAPABILITY: win32more.Windows.Win32.Foundation.HRESULT = -2145079038
WU_E_WMI_NOT_SUPPORTED: win32more.Windows.Win32.Foundation.HRESULT = -2145079037
WU_E_UPDATE_MERGE_NOT_ALLOWED: win32more.Windows.Win32.Foundation.HRESULT = -2145079036
WU_E_SKIPPED_UPDATE_INSTALLATION: win32more.Windows.Win32.Foundation.HRESULT = -2145079035
WU_E_SLS_INVALID_REVISION: win32more.Windows.Win32.Foundation.HRESULT = -2145078783
WU_E_FILETRUST_DUALSIGNATURE_RSA: win32more.Windows.Win32.Foundation.HRESULT = -2145078527
WU_E_FILETRUST_DUALSIGNATURE_ECC: win32more.Windows.Win32.Foundation.HRESULT = -2145078526
WU_E_TRUST_SUBJECT_NOT_TRUSTED: win32more.Windows.Win32.Foundation.HRESULT = -2145078525
WU_E_TRUST_PROVIDER_UNKNOWN: win32more.Windows.Win32.Foundation.HRESULT = -2145078524
AutoDownloadMode = Int32
adLetWindowsUpdateDecide: win32more.Windows.Win32.System.UpdateAgent.AutoDownloadMode = 0
adNeverAutoDownload: win32more.Windows.Win32.System.UpdateAgent.AutoDownloadMode = 1
adAlwaysAutoDownload: win32more.Windows.Win32.System.UpdateAgent.AutoDownloadMode = 2
AutoSelectionMode = Int32
asLetWindowsUpdateDecide: win32more.Windows.Win32.System.UpdateAgent.AutoSelectionMode = 0
asAutoSelectIfDownloaded: win32more.Windows.Win32.System.UpdateAgent.AutoSelectionMode = 1
asNeverAutoSelect: win32more.Windows.Win32.System.UpdateAgent.AutoSelectionMode = 2
asAlwaysAutoSelect: win32more.Windows.Win32.System.UpdateAgent.AutoSelectionMode = 3
AutomaticUpdates = Guid('{bfe18e9c-6d87-4450-b37c-e02f0b373803}')
AutomaticUpdatesNotificationLevel = Int32
aunlNotConfigured: win32more.Windows.Win32.System.UpdateAgent.AutomaticUpdatesNotificationLevel = 0
aunlDisabled: win32more.Windows.Win32.System.UpdateAgent.AutomaticUpdatesNotificationLevel = 1
aunlNotifyBeforeDownload: win32more.Windows.Win32.System.UpdateAgent.AutomaticUpdatesNotificationLevel = 2
aunlNotifyBeforeInstallation: win32more.Windows.Win32.System.UpdateAgent.AutomaticUpdatesNotificationLevel = 3
aunlScheduledInstallation: win32more.Windows.Win32.System.UpdateAgent.AutomaticUpdatesNotificationLevel = 4
AutomaticUpdatesPermissionType = Int32
auptSetNotificationLevel: win32more.Windows.Win32.System.UpdateAgent.AutomaticUpdatesPermissionType = 1
auptDisableAutomaticUpdates: win32more.Windows.Win32.System.UpdateAgent.AutomaticUpdatesPermissionType = 2
auptSetIncludeRecommendedUpdates: win32more.Windows.Win32.System.UpdateAgent.AutomaticUpdatesPermissionType = 3
auptSetFeaturedUpdatesEnabled: win32more.Windows.Win32.System.UpdateAgent.AutomaticUpdatesPermissionType = 4
auptSetNonAdministratorsElevated: win32more.Windows.Win32.System.UpdateAgent.AutomaticUpdatesPermissionType = 5
AutomaticUpdatesScheduledInstallationDay = Int32
ausidEveryDay: win32more.Windows.Win32.System.UpdateAgent.AutomaticUpdatesScheduledInstallationDay = 0
ausidEverySunday: win32more.Windows.Win32.System.UpdateAgent.AutomaticUpdatesScheduledInstallationDay = 1
ausidEveryMonday: win32more.Windows.Win32.System.UpdateAgent.AutomaticUpdatesScheduledInstallationDay = 2
ausidEveryTuesday: win32more.Windows.Win32.System.UpdateAgent.AutomaticUpdatesScheduledInstallationDay = 3
ausidEveryWednesday: win32more.Windows.Win32.System.UpdateAgent.AutomaticUpdatesScheduledInstallationDay = 4
ausidEveryThursday: win32more.Windows.Win32.System.UpdateAgent.AutomaticUpdatesScheduledInstallationDay = 5
ausidEveryFriday: win32more.Windows.Win32.System.UpdateAgent.AutomaticUpdatesScheduledInstallationDay = 6
ausidEverySaturday: win32more.Windows.Win32.System.UpdateAgent.AutomaticUpdatesScheduledInstallationDay = 7
AutomaticUpdatesUserType = Int32
auutCurrentUser: win32more.Windows.Win32.System.UpdateAgent.AutomaticUpdatesUserType = 1
auutLocalAdministrator: win32more.Windows.Win32.System.UpdateAgent.AutomaticUpdatesUserType = 2
DeploymentAction = Int32
daNone: win32more.Windows.Win32.System.UpdateAgent.DeploymentAction = 0
daInstallation: win32more.Windows.Win32.System.UpdateAgent.DeploymentAction = 1
daUninstallation: win32more.Windows.Win32.System.UpdateAgent.DeploymentAction = 2
daDetection: win32more.Windows.Win32.System.UpdateAgent.DeploymentAction = 3
daOptionalInstallation: win32more.Windows.Win32.System.UpdateAgent.DeploymentAction = 4
DownloadPhase = Int32
dphInitializing: win32more.Windows.Win32.System.UpdateAgent.DownloadPhase = 1
dphDownloading: win32more.Windows.Win32.System.UpdateAgent.DownloadPhase = 2
dphVerifying: win32more.Windows.Win32.System.UpdateAgent.DownloadPhase = 3
DownloadPriority = Int32
dpLow: win32more.Windows.Win32.System.UpdateAgent.DownloadPriority = 1
dpNormal: win32more.Windows.Win32.System.UpdateAgent.DownloadPriority = 2
dpHigh: win32more.Windows.Win32.System.UpdateAgent.DownloadPriority = 3
dpExtraHigh: win32more.Windows.Win32.System.UpdateAgent.DownloadPriority = 4
class IAutomaticUpdates(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{673425bf-c082-4c7c-bdfd-569464b8e0ce}')
    @commethod(7)
    def DetectNow(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def Pause(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def Resume(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def ShowSettingsDialog(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_Settings(self, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.IAutomaticUpdatesSettings)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_ServiceEnabled(self, retval: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def EnableService(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IAutomaticUpdates2(ComPtr):
    extends: win32more.Windows.Win32.System.UpdateAgent.IAutomaticUpdates
    _iid_ = Guid('{4a2f5c31-cfd9-410e-b7fb-29a653973a0f}')
    @commethod(14)
    def get_Results(self, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.IAutomaticUpdatesResults)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IAutomaticUpdatesResults(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{e7a4d634-7942-4dd9-a111-82228ba33901}')
    @commethod(7)
    def get_LastSearchSuccessDate(self, retval: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_LastInstallationSuccessDate(self, retval: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IAutomaticUpdatesSettings(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{2ee48f22-af3c-405f-8970-f71be12ee9a2}')
    @commethod(7)
    def get_NotificationLevel(self, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.AutomaticUpdatesNotificationLevel)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def put_NotificationLevel(self, value: win32more.Windows.Win32.System.UpdateAgent.AutomaticUpdatesNotificationLevel) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_ReadOnly(self, retval: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_Required(self, retval: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_ScheduledInstallationDay(self, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.AutomaticUpdatesScheduledInstallationDay)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def put_ScheduledInstallationDay(self, value: win32more.Windows.Win32.System.UpdateAgent.AutomaticUpdatesScheduledInstallationDay) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_ScheduledInstallationTime(self, retval: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def put_ScheduledInstallationTime(self, value: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def Refresh(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def Save(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IAutomaticUpdatesSettings2(ComPtr):
    extends: win32more.Windows.Win32.System.UpdateAgent.IAutomaticUpdatesSettings
    _iid_ = Guid('{6abc136a-c3ca-4384-8171-cb2b1e59b8dc}')
    @commethod(17)
    def get_IncludeRecommendedUpdates(self, retval: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def put_IncludeRecommendedUpdates(self, value: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def CheckPermission(self, userType: win32more.Windows.Win32.System.UpdateAgent.AutomaticUpdatesUserType, permissionType: win32more.Windows.Win32.System.UpdateAgent.AutomaticUpdatesPermissionType, userHasPermission: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IAutomaticUpdatesSettings3(ComPtr):
    extends: win32more.Windows.Win32.System.UpdateAgent.IAutomaticUpdatesSettings2
    _iid_ = Guid('{b587f5c3-f57e-485f-bbf5-0d181c5cd0dc}')
    @commethod(20)
    def get_NonAdministratorsElevated(self, retval: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def put_NonAdministratorsElevated(self, value: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def get_FeaturedUpdatesEnabled(self, retval: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def put_FeaturedUpdatesEnabled(self, value: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ICategory(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{81ddc1b8-9d35-47a6-b471-5b80f519223b}')
    @commethod(7)
    def get_Name(self, retval: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_CategoryID(self, retval: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_Children(self, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.ICategoryCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_Description(self, retval: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_Image(self, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.IImageInformation)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_Order(self, retval: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_Parent(self, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.ICategory)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_Type(self, retval: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_Updates(self, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.IUpdateCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ICategoryCollection(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{3a56bfb8-576c-43f7-9335-fe4838fd7e37}')
    @commethod(7)
    def get_Item(self, index: Int32, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.ICategory)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get__NewEnum(self, retval: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_Count(self, retval: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDownloadCompletedCallback(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{77254866-9f5b-4c8e-b9e2-c77a8530d64b}')
    @commethod(3)
    def Invoke(self, downloadJob: win32more.Windows.Win32.System.UpdateAgent.IDownloadJob, callbackArgs: win32more.Windows.Win32.System.UpdateAgent.IDownloadCompletedCallbackArgs) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDownloadCompletedCallbackArgs(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{fa565b23-498c-47a0-979d-e7d5b1813360}')
class IDownloadJob(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{c574de85-7358-43f6-aae8-8697e62d8ba7}')
    @commethod(7)
    def get_AsyncState(self, retval: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_IsCompleted(self, retval: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_Updates(self, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.IUpdateCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def CleanUp(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def GetProgress(self, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.IDownloadProgress)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def RequestAbort(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDownloadProgress(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{d31a5bac-f719-4178-9dbb-5e2cb47fd18a}')
    @commethod(7)
    def get_CurrentUpdateBytesDownloaded(self, retval: POINTER(win32more.Windows.Win32.Foundation.DECIMAL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_CurrentUpdateBytesToDownload(self, retval: POINTER(win32more.Windows.Win32.Foundation.DECIMAL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_CurrentUpdateIndex(self, retval: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_PercentComplete(self, retval: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_TotalBytesDownloaded(self, retval: POINTER(win32more.Windows.Win32.Foundation.DECIMAL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_TotalBytesToDownload(self, retval: POINTER(win32more.Windows.Win32.Foundation.DECIMAL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def GetUpdateResult(self, updateIndex: Int32, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.IUpdateDownloadResult)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_CurrentUpdateDownloadPhase(self, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.DownloadPhase)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_CurrentUpdatePercentComplete(self, retval: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDownloadProgressChangedCallback(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{8c3f1cdd-6173-4591-aebd-a56a53ca77c1}')
    @commethod(3)
    def Invoke(self, downloadJob: win32more.Windows.Win32.System.UpdateAgent.IDownloadJob, callbackArgs: win32more.Windows.Win32.System.UpdateAgent.IDownloadProgressChangedCallbackArgs) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDownloadProgressChangedCallbackArgs(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{324ff2c6-4981-4b04-9412-57481745ab24}')
    @commethod(7)
    def get_Progress(self, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.IDownloadProgress)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IDownloadResult(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{daa4fdd0-4727-4dbe-a1e7-745dca317144}')
    @commethod(7)
    def get_HResult(self, retval: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_ResultCode(self, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.OperationResultCode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def GetUpdateResult(self, updateIndex: Int32, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.IUpdateDownloadResult)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IImageInformation(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{7c907864-346c-4aeb-8f3f-57da289f969f}')
    @commethod(7)
    def get_AltText(self, retval: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_Height(self, retval: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_Source(self, retval: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_Width(self, retval: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IInstallationAgent(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{925cbc18-a2ea-4648-bf1c-ec8badcfe20a}')
    @commethod(7)
    def RecordInstallationResult(self, installationResultCookie: win32more.Windows.Win32.Foundation.BSTR, hresult: Int32, extendedReportingData: win32more.Windows.Win32.System.UpdateAgent.IStringCollection) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IInstallationBehavior(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{d9a59339-e245-4dbd-9686-4d5763e39624}')
    @commethod(7)
    def get_CanRequestUserInput(self, retval: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_Impact(self, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.InstallationImpact)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_RebootBehavior(self, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.InstallationRebootBehavior)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_RequiresNetworkConnectivity(self, retval: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IInstallationCompletedCallback(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{45f4f6f3-d602-4f98-9a8a-3efa152ad2d3}')
    @commethod(3)
    def Invoke(self, installationJob: win32more.Windows.Win32.System.UpdateAgent.IInstallationJob, callbackArgs: win32more.Windows.Win32.System.UpdateAgent.IInstallationCompletedCallbackArgs) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IInstallationCompletedCallbackArgs(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{250e2106-8efb-4705-9653-ef13c581b6a1}')
class IInstallationJob(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{5c209f0b-bad5-432a-9556-4699bed2638a}')
    @commethod(7)
    def get_AsyncState(self, retval: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_IsCompleted(self, retval: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_Updates(self, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.IUpdateCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def CleanUp(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def GetProgress(self, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.IInstallationProgress)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def RequestAbort(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IInstallationProgress(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{345c8244-43a3-4e32-a368-65f073b76f36}')
    @commethod(7)
    def get_CurrentUpdateIndex(self, retval: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_CurrentUpdatePercentComplete(self, retval: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_PercentComplete(self, retval: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetUpdateResult(self, updateIndex: Int32, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.IUpdateInstallationResult)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IInstallationProgressChangedCallback(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{e01402d5-f8da-43ba-a012-38894bd048f1}')
    @commethod(3)
    def Invoke(self, installationJob: win32more.Windows.Win32.System.UpdateAgent.IInstallationJob, callbackArgs: win32more.Windows.Win32.System.UpdateAgent.IInstallationProgressChangedCallbackArgs) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IInstallationProgressChangedCallbackArgs(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{e4f14e1e-689d-4218-a0b9-bc189c484a01}')
    @commethod(7)
    def get_Progress(self, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.IInstallationProgress)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IInstallationResult(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{a43c56d6-7451-48d4-af96-b6cd2d0d9b7a}')
    @commethod(7)
    def get_HResult(self, retval: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_RebootRequired(self, retval: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_ResultCode(self, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.OperationResultCode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def GetUpdateResult(self, updateIndex: Int32, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.IUpdateInstallationResult)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IInvalidProductLicenseException(ComPtr):
    extends: win32more.Windows.Win32.System.UpdateAgent.IUpdateException
    _iid_ = Guid('{a37d00f5-7bb0-4953-b414-f9e98326f2e8}')
    @commethod(10)
    def get_Product(self, retval: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISearchCompletedCallback(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{88aee058-d4b0-4725-a2f1-814a67ae964c}')
    @commethod(3)
    def Invoke(self, searchJob: win32more.Windows.Win32.System.UpdateAgent.ISearchJob, callbackArgs: win32more.Windows.Win32.System.UpdateAgent.ISearchCompletedCallbackArgs) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISearchCompletedCallbackArgs(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{a700a634-2850-4c47-938a-9e4b6e5af9a6}')
class ISearchJob(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{7366ea16-7a1a-4ea2-b042-973d3e9cd99b}')
    @commethod(7)
    def get_AsyncState(self, retval: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_IsCompleted(self, retval: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def CleanUp(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def RequestAbort(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISearchResult(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{d40cff62-e08c-4498-941a-01e25f0fd33c}')
    @commethod(7)
    def get_ResultCode(self, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.OperationResultCode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_RootCategories(self, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.ICategoryCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_Updates(self, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.IUpdateCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_Warnings(self, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.IUpdateExceptionCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IStringCollection(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{eff90582-2ddc-480f-a06d-60f3fbc362c3}')
    @commethod(7)
    def get_Item(self, index: Int32, retval: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def put_Item(self, index: Int32, value: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get__NewEnum(self, retval: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_Count(self, retval: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_ReadOnly(self, retval: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def Add(self, value: win32more.Windows.Win32.Foundation.BSTR, retval: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def Clear(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def Copy(self, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.IStringCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def Insert(self, index: Int32, value: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def RemoveAt(self, index: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class ISystemInformation(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{ade87bf7-7b56-4275-8fab-b9b0e591844b}')
    @commethod(7)
    def get_OemHardwareSupportLink(self, retval: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_RebootRequired(self, retval: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUpdate(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{6a92b07a-d821-4682-b423-5c805022cc4d}')
    @commethod(7)
    def get_Title(self, retval: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_AutoSelectOnWebSites(self, retval: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_BundledUpdates(self, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.IUpdateCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_CanRequireSource(self, retval: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_Categories(self, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.ICategoryCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_Deadline(self, retval: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_DeltaCompressedContentAvailable(self, retval: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_DeltaCompressedContentPreferred(self, retval: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_Description(self, retval: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_EulaAccepted(self, retval: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def get_EulaText(self, retval: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_HandlerID(self, retval: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def get_Identity(self, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.IUpdateIdentity)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def get_Image(self, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.IImageInformation)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def get_InstallationBehavior(self, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.IInstallationBehavior)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def get_IsBeta(self, retval: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def get_IsDownloaded(self, retval: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def get_IsHidden(self, retval: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def put_IsHidden(self, value: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def get_IsInstalled(self, retval: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def get_IsMandatory(self, retval: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def get_IsUninstallable(self, retval: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def get_Languages(self, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.IStringCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(30)
    def get_LastDeploymentChangeTime(self, retval: POINTER(Double)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def get_MaxDownloadSize(self, retval: POINTER(win32more.Windows.Win32.Foundation.DECIMAL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(32)
    def get_MinDownloadSize(self, retval: POINTER(win32more.Windows.Win32.Foundation.DECIMAL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(33)
    def get_MoreInfoUrls(self, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.IStringCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(34)
    def get_MsrcSeverity(self, retval: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(35)
    def get_RecommendedCpuSpeed(self, retval: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(36)
    def get_RecommendedHardDiskSpace(self, retval: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(37)
    def get_RecommendedMemory(self, retval: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(38)
    def get_ReleaseNotes(self, retval: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(39)
    def get_SecurityBulletinIDs(self, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.IStringCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(40)
    def get_SupersededUpdateIDs(self, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.IStringCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(41)
    def get_SupportUrl(self, retval: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(42)
    def get_Type(self, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.UpdateType)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(43)
    def get_UninstallationNotes(self, retval: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(44)
    def get_UninstallationBehavior(self, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.IInstallationBehavior)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(45)
    def get_UninstallationSteps(self, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.IStringCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(46)
    def get_KBArticleIDs(self, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.IStringCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(47)
    def AcceptEula(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(48)
    def get_DeploymentAction(self, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.DeploymentAction)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(49)
    def CopyFromCache(self, path: win32more.Windows.Win32.Foundation.BSTR, toExtractCabFiles: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(50)
    def get_DownloadPriority(self, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.DownloadPriority)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(51)
    def get_DownloadContents(self, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.IUpdateDownloadContentCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUpdate2(ComPtr):
    extends: win32more.Windows.Win32.System.UpdateAgent.IUpdate
    _iid_ = Guid('{144fe9b0-d23d-4a8b-8634-fb4457533b7a}')
    @commethod(52)
    def get_RebootRequired(self, retval: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(53)
    def get_IsPresent(self, retval: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(54)
    def get_CveIDs(self, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.IStringCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(55)
    def CopyToCache(self, pFiles: win32more.Windows.Win32.System.UpdateAgent.IStringCollection) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUpdate3(ComPtr):
    extends: win32more.Windows.Win32.System.UpdateAgent.IUpdate2
    _iid_ = Guid('{112eda6b-95b3-476f-9d90-aee82c6b8181}')
    @commethod(56)
    def get_BrowseOnly(self, retval: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUpdate4(ComPtr):
    extends: win32more.Windows.Win32.System.UpdateAgent.IUpdate3
    _iid_ = Guid('{27e94b0d-5139-49a2-9a61-93522dc54652}')
    @commethod(57)
    def get_PerUser(self, retval: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUpdate5(ComPtr):
    extends: win32more.Windows.Win32.System.UpdateAgent.IUpdate4
    _iid_ = Guid('{c1c2f21a-d2f4-4902-b5c6-8a081c19a890}')
    @commethod(58)
    def get_AutoSelection(self, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.AutoSelectionMode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(59)
    def get_AutoDownload(self, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.AutoDownloadMode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUpdateCollection(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{07f7438c-7709-4ca5-b518-91279288134e}')
    @commethod(7)
    def get_Item(self, index: Int32, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.IUpdate)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def put_Item(self, index: Int32, value: win32more.Windows.Win32.System.UpdateAgent.IUpdate) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get__NewEnum(self, retval: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_Count(self, retval: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_ReadOnly(self, retval: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def Add(self, value: win32more.Windows.Win32.System.UpdateAgent.IUpdate, retval: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def Clear(self) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def Copy(self, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.IUpdateCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def Insert(self, index: Int32, value: win32more.Windows.Win32.System.UpdateAgent.IUpdate) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def RemoveAt(self, index: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUpdateDownloadContent(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{54a2cb2d-9a0c-48b6-8a50-9abb69ee2d02}')
    @commethod(7)
    def get_DownloadUrl(self, retval: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUpdateDownloadContent2(ComPtr):
    extends: win32more.Windows.Win32.System.UpdateAgent.IUpdateDownloadContent
    _iid_ = Guid('{c97ad11b-f257-420b-9d9f-377f733f6f68}')
    @commethod(8)
    def get_IsDeltaCompressedContent(self, retval: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUpdateDownloadContentCollection(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{bc5513c8-b3b8-4bf7-a4d4-361c0d8c88ba}')
    @commethod(7)
    def get_Item(self, index: Int32, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.IUpdateDownloadContent)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get__NewEnum(self, retval: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_Count(self, retval: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUpdateDownloadResult(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{bf99af76-b575-42ad-8aa4-33cbb5477af1}')
    @commethod(7)
    def get_HResult(self, retval: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_ResultCode(self, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.OperationResultCode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUpdateDownloader(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{68f1c6f9-7ecc-4666-a464-247fe12496c3}')
    @commethod(7)
    def get_ClientApplicationID(self, retval: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def put_ClientApplicationID(self, value: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_IsForced(self, retval: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def put_IsForced(self, value: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_Priority(self, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.DownloadPriority)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def put_Priority(self, value: win32more.Windows.Win32.System.UpdateAgent.DownloadPriority) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_Updates(self, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.IUpdateCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def put_Updates(self, value: win32more.Windows.Win32.System.UpdateAgent.IUpdateCollection) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def BeginDownload(self, onProgressChanged: win32more.Windows.Win32.System.Com.IUnknown, onCompleted: win32more.Windows.Win32.System.Com.IUnknown, state: win32more.Windows.Win32.System.Variant.VARIANT, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.IDownloadJob)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def Download(self, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.IDownloadResult)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def EndDownload(self, value: win32more.Windows.Win32.System.UpdateAgent.IDownloadJob, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.IDownloadResult)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUpdateException(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{a376dd5e-09d4-427f-af7c-fed5b6e1c1d6}')
    @commethod(7)
    def get_Message(self, retval: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_HResult(self, retval: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_Context(self, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.UpdateExceptionContext)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUpdateExceptionCollection(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{503626a3-8e14-4729-9355-0fe664bd2321}')
    @commethod(7)
    def get_Item(self, index: Int32, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.IUpdateException)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get__NewEnum(self, retval: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_Count(self, retval: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUpdateHistoryEntry(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{be56a644-af0e-4e0e-a311-c1d8e695cbff}')
    @commethod(7)
    def get_Operation(self, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.UpdateOperation)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_ResultCode(self, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.OperationResultCode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_HResult(self, retval: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_Date(self, retval: POINTER(Double)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_UpdateIdentity(self, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.IUpdateIdentity)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_Title(self, retval: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_Description(self, retval: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_UnmappedResultCode(self, retval: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_ClientApplicationID(self, retval: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_ServerSelection(self, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.ServerSelection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def get_ServiceID(self, retval: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_UninstallationSteps(self, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.IStringCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def get_UninstallationNotes(self, retval: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def get_SupportUrl(self, retval: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUpdateHistoryEntry2(ComPtr):
    extends: win32more.Windows.Win32.System.UpdateAgent.IUpdateHistoryEntry
    _iid_ = Guid('{c2bfb780-4539-4132-ab8c-0a8772013ab6}')
    @commethod(21)
    def get_Categories(self, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.ICategoryCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUpdateHistoryEntryCollection(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{a7f04f3c-a290-435b-aadf-a116c3357a5c}')
    @commethod(7)
    def get_Item(self, index: Int32, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.IUpdateHistoryEntry)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get__NewEnum(self, retval: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_Count(self, retval: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUpdateIdentity(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{46297823-9940-4c09-aed9-cd3ea6d05968}')
    @commethod(7)
    def get_RevisionNumber(self, retval: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_UpdateID(self, retval: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUpdateInstallationResult(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{d940f0f8-3cbb-4fd0-993f-471e7f2328ad}')
    @commethod(7)
    def get_HResult(self, retval: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_RebootRequired(self, retval: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_ResultCode(self, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.OperationResultCode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUpdateInstaller(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{7b929c68-ccdc-4226-96b1-8724600b54c2}')
    @commethod(7)
    def get_ClientApplicationID(self, retval: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def put_ClientApplicationID(self, value: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_IsForced(self, retval: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def put_IsForced(self, value: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_ParentHwnd(self, retval: POINTER(win32more.Windows.Win32.Foundation.HWND)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def put_ParentHwnd(self, value: win32more.Windows.Win32.Foundation.HWND) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def put_ParentWindow(self, value: win32more.Windows.Win32.System.Com.IUnknown) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_ParentWindow(self, retval: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_Updates(self, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.IUpdateCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def put_Updates(self, value: win32more.Windows.Win32.System.UpdateAgent.IUpdateCollection) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def BeginInstall(self, onProgressChanged: win32more.Windows.Win32.System.Com.IUnknown, onCompleted: win32more.Windows.Win32.System.Com.IUnknown, state: win32more.Windows.Win32.System.Variant.VARIANT, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.IInstallationJob)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def BeginUninstall(self, onProgressChanged: win32more.Windows.Win32.System.Com.IUnknown, onCompleted: win32more.Windows.Win32.System.Com.IUnknown, state: win32more.Windows.Win32.System.Variant.VARIANT, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.IInstallationJob)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def EndInstall(self, value: win32more.Windows.Win32.System.UpdateAgent.IInstallationJob, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.IInstallationResult)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def EndUninstall(self, value: win32more.Windows.Win32.System.UpdateAgent.IInstallationJob, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.IInstallationResult)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def Install(self, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.IInstallationResult)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def RunWizard(self, dialogTitle: win32more.Windows.Win32.Foundation.BSTR, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.IInstallationResult)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def get_IsBusy(self, retval: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def Uninstall(self, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.IInstallationResult)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(25)
    def get_AllowSourcePrompts(self, retval: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def put_AllowSourcePrompts(self, value: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(27)
    def get_RebootRequiredBeforeInstallation(self, retval: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUpdateInstaller2(ComPtr):
    extends: win32more.Windows.Win32.System.UpdateAgent.IUpdateInstaller
    _iid_ = Guid('{3442d4fe-224d-4cee-98cf-30e0c4d229e6}')
    @commethod(28)
    def get_ForceQuiet(self, retval: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(29)
    def put_ForceQuiet(self, value: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUpdateInstaller3(ComPtr):
    extends: win32more.Windows.Win32.System.UpdateAgent.IUpdateInstaller2
    _iid_ = Guid('{16d11c35-099a-48d0-8338-5fae64047f8e}')
    @commethod(30)
    def get_AttemptCloseAppsIfNecessary(self, retval: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(31)
    def put_AttemptCloseAppsIfNecessary(self, value: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUpdateInstaller4(ComPtr):
    extends: win32more.Windows.Win32.System.UpdateAgent.IUpdateInstaller3
    _iid_ = Guid('{ef8208ea-2304-492d-9109-23813b0958e1}')
    @commethod(32)
    def Commit(self, dwFlags: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUpdateLockdown(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IUnknown
    _iid_ = Guid('{a976c28d-75a1-42aa-94ae-8af8b872089a}')
    @commethod(3)
    def LockDown(self, flags: Int32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUpdateSearcher(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{8f45abf1-f9ae-4b95-a933-f0f66e5056ea}')
    @commethod(7)
    def get_CanAutomaticallyUpgradeService(self, retval: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def put_CanAutomaticallyUpgradeService(self, value: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_ClientApplicationID(self, retval: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def put_ClientApplicationID(self, value: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_IncludePotentiallySupersededUpdates(self, retval: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def put_IncludePotentiallySupersededUpdates(self, value: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_ServerSelection(self, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.ServerSelection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def put_ServerSelection(self, value: win32more.Windows.Win32.System.UpdateAgent.ServerSelection) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def BeginSearch(self, criteria: win32more.Windows.Win32.Foundation.BSTR, onCompleted: win32more.Windows.Win32.System.Com.IUnknown, state: win32more.Windows.Win32.System.Variant.VARIANT, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.ISearchJob)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def EndSearch(self, searchJob: win32more.Windows.Win32.System.UpdateAgent.ISearchJob, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.ISearchResult)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def EscapeString(self, unescaped: win32more.Windows.Win32.Foundation.BSTR, retval: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def QueryHistory(self, startIndex: Int32, count: Int32, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.IUpdateHistoryEntryCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def Search(self, criteria: win32more.Windows.Win32.Foundation.BSTR, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.ISearchResult)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def get_Online(self, retval: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(21)
    def put_Online(self, value: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(22)
    def GetTotalHistoryCount(self, retval: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(23)
    def get_ServiceID(self, retval: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(24)
    def put_ServiceID(self, value: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUpdateSearcher2(ComPtr):
    extends: win32more.Windows.Win32.System.UpdateAgent.IUpdateSearcher
    _iid_ = Guid('{4cbdcb2d-1589-4beb-bd1c-3e582ff0add0}')
    @commethod(25)
    def get_IgnoreDownloadPriority(self, retval: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(26)
    def put_IgnoreDownloadPriority(self, value: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUpdateSearcher3(ComPtr):
    extends: win32more.Windows.Win32.System.UpdateAgent.IUpdateSearcher2
    _iid_ = Guid('{04c6895d-eaf2-4034-97f3-311de9be413a}')
    @commethod(27)
    def get_SearchScope(self, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.SearchScope)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(28)
    def put_SearchScope(self, value: win32more.Windows.Win32.System.UpdateAgent.SearchScope) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUpdateService(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{76b3b17e-aed6-4da5-85f0-83587f81abe3}')
    @commethod(7)
    def get_Name(self, retval: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_ContentValidationCert(self, retval: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_ExpirationDate(self, retval: POINTER(Double)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_IsManaged(self, retval: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_IsRegisteredWithAU(self, retval: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_IssueDate(self, retval: POINTER(Double)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_OffersWindowsUpdates(self, retval: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_RedirectUrls(self, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.IStringCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def get_ServiceID(self, retval: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def get_IsScanPackageService(self, retval: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def get_CanRegisterWithAU(self, retval: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def get_ServiceUrl(self, retval: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def get_SetupPrefix(self, retval: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUpdateService2(ComPtr):
    extends: win32more.Windows.Win32.System.UpdateAgent.IUpdateService
    _iid_ = Guid('{1518b460-6518-4172-940f-c75883b24ceb}')
    @commethod(20)
    def get_IsDefaultAUService(self, retval: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUpdateServiceCollection(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{9b0353aa-0e52-44ff-b8b0-1f7fa0437f88}')
    @commethod(7)
    def get_Item(self, index: Int32, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.IUpdateService)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get__NewEnum(self, retval: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_Count(self, retval: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUpdateServiceManager(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{23857e3c-02ba-44a3-9423-b1c900805f37}')
    @commethod(7)
    def get_Services(self, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.IUpdateServiceCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def AddService(self, serviceID: win32more.Windows.Win32.Foundation.BSTR, authorizationCabPath: win32more.Windows.Win32.Foundation.BSTR, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.IUpdateService)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def RegisterServiceWithAU(self, serviceID: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def RemoveService(self, serviceID: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def UnregisterServiceWithAU(self, serviceID: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def AddScanPackageService(self, serviceName: win32more.Windows.Win32.Foundation.BSTR, scanFileLocation: win32more.Windows.Win32.Foundation.BSTR, flags: Int32, ppService: POINTER(win32more.Windows.Win32.System.UpdateAgent.IUpdateService)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def SetOption(self, optionName: win32more.Windows.Win32.Foundation.BSTR, optionValue: win32more.Windows.Win32.System.Variant.VARIANT) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUpdateServiceManager2(ComPtr):
    extends: win32more.Windows.Win32.System.UpdateAgent.IUpdateServiceManager
    _iid_ = Guid('{0bb8531d-7e8d-424f-986c-a0b8f60a3e7b}')
    @commethod(14)
    def get_ClientApplicationID(self, retval: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def put_ClientApplicationID(self, value: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def QueryServiceRegistration(self, serviceID: win32more.Windows.Win32.Foundation.BSTR, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.IUpdateServiceRegistration)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def AddService2(self, serviceID: win32more.Windows.Win32.Foundation.BSTR, flags: Int32, authorizationCabPath: win32more.Windows.Win32.Foundation.BSTR, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.IUpdateServiceRegistration)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUpdateServiceRegistration(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{dde02280-12b3-4e0b-937b-6747f6acb286}')
    @commethod(7)
    def get_RegistrationState(self, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.UpdateServiceRegistrationState)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_ServiceID(self, retval: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_IsPendingRegistrationWithAU(self, retval: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_Service(self, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.IUpdateService2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUpdateSession(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{816858a4-260d-4260-933a-2585f1abc76b}')
    @commethod(7)
    def get_ClientApplicationID(self, retval: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def put_ClientApplicationID(self, value: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_ReadOnly(self, retval: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_WebProxy(self, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.IWebProxy)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def put_WebProxy(self, value: win32more.Windows.Win32.System.UpdateAgent.IWebProxy) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def CreateUpdateSearcher(self, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.IUpdateSearcher)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def CreateUpdateDownloader(self, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.IUpdateDownloader)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def CreateUpdateInstaller(self, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.IUpdateInstaller)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUpdateSession2(ComPtr):
    extends: win32more.Windows.Win32.System.UpdateAgent.IUpdateSession
    _iid_ = Guid('{91caf7b0-eb23-49ed-9937-c52d817f46f7}')
    @commethod(15)
    def get_UserLocale(self, retval: POINTER(UInt32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def put_UserLocale(self, lcid: UInt32) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IUpdateSession3(ComPtr):
    extends: win32more.Windows.Win32.System.UpdateAgent.IUpdateSession2
    _iid_ = Guid('{918efd1e-b5d8-4c90-8540-aeb9bdc56f9d}')
    @commethod(17)
    def CreateUpdateServiceManager(self, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.IUpdateServiceManager2)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def QueryHistory(self, criteria: win32more.Windows.Win32.Foundation.BSTR, startIndex: Int32, count: Int32, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.IUpdateHistoryEntryCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWebProxy(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{174c81fe-aecd-4dae-b8a0-2c6318dd86a8}')
    @commethod(7)
    def get_Address(self, retval: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def put_Address(self, value: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_BypassList(self, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.IStringCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def put_BypassList(self, value: win32more.Windows.Win32.System.UpdateAgent.IStringCollection) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_BypassProxyOnLocal(self, retval: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def put_BypassProxyOnLocal(self, value: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_ReadOnly(self, retval: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_UserName(self, retval: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(15)
    def put_UserName(self, value: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(16)
    def SetPassword(self, value: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(17)
    def PromptForCredentials(self, parentWindow: win32more.Windows.Win32.System.Com.IUnknown, title: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(18)
    def PromptForCredentialsFromHwnd(self, parentWindow: win32more.Windows.Win32.Foundation.HWND, title: win32more.Windows.Win32.Foundation.BSTR) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(19)
    def get_AutoDetect(self, retval: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(20)
    def put_AutoDetect(self, value: win32more.Windows.Win32.Foundation.VARIANT_BOOL) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWindowsDriverUpdate(ComPtr):
    extends: win32more.Windows.Win32.System.UpdateAgent.IUpdate
    _iid_ = Guid('{b383cd1a-5ce9-4504-9f63-764b1236f191}')
    @commethod(52)
    def get_DriverClass(self, retval: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(53)
    def get_DriverHardwareID(self, retval: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(54)
    def get_DriverManufacturer(self, retval: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(55)
    def get_DriverModel(self, retval: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(56)
    def get_DriverProvider(self, retval: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(57)
    def get_DriverVerDate(self, retval: POINTER(Double)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(58)
    def get_DeviceProblemNumber(self, retval: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(59)
    def get_DeviceStatus(self, retval: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWindowsDriverUpdate2(ComPtr):
    extends: win32more.Windows.Win32.System.UpdateAgent.IWindowsDriverUpdate
    _iid_ = Guid('{615c4269-7a48-43bd-96b7-bf6ca27d6c3e}')
    @commethod(60)
    def get_RebootRequired(self, retval: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(61)
    def get_IsPresent(self, retval: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(62)
    def get_CveIDs(self, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.IStringCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(63)
    def CopyToCache(self, pFiles: win32more.Windows.Win32.System.UpdateAgent.IStringCollection) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWindowsDriverUpdate3(ComPtr):
    extends: win32more.Windows.Win32.System.UpdateAgent.IWindowsDriverUpdate2
    _iid_ = Guid('{49ebd502-4a96-41bd-9e3e-4c5057f4250c}')
    @commethod(64)
    def get_BrowseOnly(self, retval: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWindowsDriverUpdate4(ComPtr):
    extends: win32more.Windows.Win32.System.UpdateAgent.IWindowsDriverUpdate3
    _iid_ = Guid('{004c6a2b-0c19-4c69-9f5c-a269b2560db9}')
    @commethod(65)
    def get_WindowsDriverUpdateEntries(self, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.IWindowsDriverUpdateEntryCollection)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(66)
    def get_PerUser(self, retval: POINTER(win32more.Windows.Win32.Foundation.VARIANT_BOOL)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWindowsDriverUpdate5(ComPtr):
    extends: win32more.Windows.Win32.System.UpdateAgent.IWindowsDriverUpdate4
    _iid_ = Guid('{70cf5c82-8642-42bb-9dbc-0cfd263c6c4f}')
    @commethod(67)
    def get_AutoSelection(self, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.AutoSelectionMode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(68)
    def get_AutoDownload(self, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.AutoDownloadMode)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWindowsDriverUpdateEntry(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{ed8bfe40-a60b-42ea-9652-817dfcfa23ec}')
    @commethod(7)
    def get_DriverClass(self, retval: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get_DriverHardwareID(self, retval: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_DriverManufacturer(self, retval: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(10)
    def get_DriverModel(self, retval: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(11)
    def get_DriverProvider(self, retval: POINTER(win32more.Windows.Win32.Foundation.BSTR)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(12)
    def get_DriverVerDate(self, retval: POINTER(Double)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(13)
    def get_DeviceProblemNumber(self, retval: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(14)
    def get_DeviceStatus(self, retval: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWindowsDriverUpdateEntryCollection(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{0d521700-a372-4bef-828b-3d00c10adebd}')
    @commethod(7)
    def get_Item(self, index: Int32, retval: POINTER(win32more.Windows.Win32.System.UpdateAgent.IWindowsDriverUpdateEntry)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(8)
    def get__NewEnum(self, retval: POINTER(win32more.Windows.Win32.System.Com.IUnknown)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
    @commethod(9)
    def get_Count(self, retval: POINTER(Int32)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
class IWindowsUpdateAgentInfo(ComPtr):
    extends: win32more.Windows.Win32.System.Com.IDispatch
    _iid_ = Guid('{85713fa1-7796-4fa2-be3b-e2d6124dd373}')
    @commethod(7)
    def GetInfo(self, varInfoIdentifier: win32more.Windows.Win32.System.Variant.VARIANT, retval: POINTER(win32more.Windows.Win32.System.Variant.VARIANT)) -> win32more.Windows.Win32.Foundation.HRESULT: ...
InstallationAgent = Guid('{317e92fc-1679-46fd-a0b5-f08914dd8623}')
InstallationImpact = Int32
iiNormal: win32more.Windows.Win32.System.UpdateAgent.InstallationImpact = 0
iiMinor: win32more.Windows.Win32.System.UpdateAgent.InstallationImpact = 1
iiRequiresExclusiveHandling: win32more.Windows.Win32.System.UpdateAgent.InstallationImpact = 2
InstallationRebootBehavior = Int32
irbNeverReboots: win32more.Windows.Win32.System.UpdateAgent.InstallationRebootBehavior = 0
irbAlwaysRequiresReboot: win32more.Windows.Win32.System.UpdateAgent.InstallationRebootBehavior = 1
irbCanRequestReboot: win32more.Windows.Win32.System.UpdateAgent.InstallationRebootBehavior = 2
OperationResultCode = Int32
orcNotStarted: win32more.Windows.Win32.System.UpdateAgent.OperationResultCode = 0
orcInProgress: win32more.Windows.Win32.System.UpdateAgent.OperationResultCode = 1
orcSucceeded: win32more.Windows.Win32.System.UpdateAgent.OperationResultCode = 2
orcSucceededWithErrors: win32more.Windows.Win32.System.UpdateAgent.OperationResultCode = 3
orcFailed: win32more.Windows.Win32.System.UpdateAgent.OperationResultCode = 4
orcAborted: win32more.Windows.Win32.System.UpdateAgent.OperationResultCode = 5
SearchScope = Int32
searchScopeDefault: win32more.Windows.Win32.System.UpdateAgent.SearchScope = 0
searchScopeMachineOnly: win32more.Windows.Win32.System.UpdateAgent.SearchScope = 1
searchScopeCurrentUserOnly: win32more.Windows.Win32.System.UpdateAgent.SearchScope = 2
searchScopeMachineAndCurrentUser: win32more.Windows.Win32.System.UpdateAgent.SearchScope = 3
searchScopeMachineAndAllUsers: win32more.Windows.Win32.System.UpdateAgent.SearchScope = 4
searchScopeAllUsers: win32more.Windows.Win32.System.UpdateAgent.SearchScope = 5
ServerSelection = Int32
ssDefault: win32more.Windows.Win32.System.UpdateAgent.ServerSelection = 0
ssManagedServer: win32more.Windows.Win32.System.UpdateAgent.ServerSelection = 1
ssWindowsUpdate: win32more.Windows.Win32.System.UpdateAgent.ServerSelection = 2
ssOthers: win32more.Windows.Win32.System.UpdateAgent.ServerSelection = 3
StringCollection = Guid('{72c97d74-7c3b-40ae-b77d-abdb22eba6fb}')
SystemInformation = Guid('{c01b9ba0-bea7-41ba-b604-d0a36f469133}')
UpdateCollection = Guid('{13639463-00db-4646-803d-528026140d88}')
UpdateDownloader = Guid('{5baf654a-5a07-4264-a255-9ff54c7151e7}')
UpdateExceptionContext = Int32
uecGeneral: win32more.Windows.Win32.System.UpdateAgent.UpdateExceptionContext = 1
uecWindowsDriver: win32more.Windows.Win32.System.UpdateAgent.UpdateExceptionContext = 2
uecWindowsInstaller: win32more.Windows.Win32.System.UpdateAgent.UpdateExceptionContext = 3
uecSearchIncomplete: win32more.Windows.Win32.System.UpdateAgent.UpdateExceptionContext = 4
UpdateInstaller = Guid('{d2e0fe7f-d23e-48e1-93c0-6fa8cc346474}')
UpdateLockdownOption = Int32
uloForWebsiteAccess: win32more.Windows.Win32.System.UpdateAgent.UpdateLockdownOption = 1
UpdateOperation = Int32
uoInstallation: win32more.Windows.Win32.System.UpdateAgent.UpdateOperation = 1
uoUninstallation: win32more.Windows.Win32.System.UpdateAgent.UpdateOperation = 2
UpdateSearcher = Guid('{b699e5e8-67ff-4177-88b0-3684a3388bfb}')
UpdateServiceManager = Guid('{f8d253d9-89a4-4daa-87b6-1168369f0b21}')
UpdateServiceOption = Int32
usoNonVolatileService: win32more.Windows.Win32.System.UpdateAgent.UpdateServiceOption = 1
UpdateServiceRegistrationState = Int32
usrsNotRegistered: win32more.Windows.Win32.System.UpdateAgent.UpdateServiceRegistrationState = 1
usrsRegistrationPending: win32more.Windows.Win32.System.UpdateAgent.UpdateServiceRegistrationState = 2
usrsRegistered: win32more.Windows.Win32.System.UpdateAgent.UpdateServiceRegistrationState = 3
UpdateSession = Guid('{4cb43d7f-7eee-4906-8698-60da1c38f2fe}')
UpdateType = Int32
utSoftware: win32more.Windows.Win32.System.UpdateAgent.UpdateType = 1
utDriver: win32more.Windows.Win32.System.UpdateAgent.UpdateType = 2
WebProxy = Guid('{650503cf-9108-4ddc-a2ce-6c2341e1c582}')
WindowsUpdateAgentInfo = Guid('{c2e88c2f-6f5b-4aaa-894b-55c847ad3a2d}')


make_ready(__name__)
